pub struct Can { /* private fields */ }Expand description
CAN.
Implementations
Sourceimpl Can
impl Can
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn flt_dlc(self) -> Reg<FltDlc, RW>
pub const fn flt_dlc(self) -> Reg<FltDlc, RW>
Pretended Networking Data Length Code (DLC) Filter.
Sourcepub const fn flt_id2_idmask(self) -> Reg<FltId2Idmask, RW>
pub const fn flt_id2_idmask(self) -> Reg<FltId2Idmask, RW>
Pretended Networking ID Filter 2 or ID Mask.
Sourcepub const fn pl2_plmask_lo(self) -> Reg<Pl2PlmaskLo, RW>
pub const fn pl2_plmask_lo(self) -> Reg<Pl2PlmaskLo, RW>
Pretended Networking Payload Low Filter 2 and Payload Low Mask.
Sourcepub const fn pl2_plmask_hi(self) -> Reg<Pl2PlmaskHi, RW>
pub const fn pl2_plmask_hi(self) -> Reg<Pl2PlmaskHi, RW>
Pretended Networking Payload High Filter 2 and Payload High Mask.
Sourcepub const fn erfifo_cs(self) -> Reg<Cs, R>
pub const fn erfifo_cs(self) -> Reg<Cs, R>
Enhanced RX FIFO output element CS field. Reads the CS word of the oldest element in the Enhanced RX FIFO.
Sourcepub const fn erfifo_id(self) -> Reg<Id, R>
pub const fn erfifo_id(self) -> Reg<Id, R>
Enhanced RX FIFO output element ID field. Reads the ID word of the oldest element in the Enhanced RX FIFO.